Publications
============

How to cite
-----------

When citing PyHMMER, please additionally cite HMMER, which developed the actual
method and is wrapped with PyHMMER. You can for instance cite both papers as:
*PyHMMER (Larralde et al., 2022), a Python library binding to HMMER (Eddy, 2011).*

Sean Eddy states in the `HMMER manual <http://eddylab.org/software/hmmer/Userguide.pdf>`_
that you should cite the HMMER website if possible, and only resort to the 2011
publication (:doi:`10.1371/journal.pcbi.1002195`) for journals that cause
problems. You can grab a `BibTex file <_static/bibtex/citation.bib>`_ with
the different publications.


Citations
---------

PyHMMER has been used in the following research works:

- Bhandari, B.K., Goldman, N. *A generalised protein identification method for novel and diverse sequencing technologies* (preprint). bioRxiv. :doi:`10.1101/2024.02.29.582769`.
- Carroll, L.M., M. Larralde, J.S. Fleck, R. Ponnudurai, A. Milanese, E. Cappio, G. Zeller, 2021. *Accurate de novo identification of biosynthetic gene clusters with GECCO* (preprint). bioRxiv. :doi:`10.1101/2021.05.03.442509`.
- Ducarmon, Q.R., N. Karcher, H.L.P. Tytgat, O. Delannoy-Bruno, S. Pekel, F. Springer, C. Schudoma, G. Zeller. *Large-scale computational analyses of gut microbial CAZyme repertoires enabled by Cayman* (preprint). bioRxiv. :doi:`10.1101/2024.01.08.574624`.
- Erdrich, S.H., Luthe, T., Kever, L., Roigé, B.B., Arsova, B., Davoudi, E., Frunzke, J. *Expanding the phage galaxy: Isolation and characterization of five novel Streptomyces siphoviruses Ankus, Byblos, DekoNeimoidia, Mandalore, and Naboo* (preprint). bioRxiv. :doi:`10.1101/2024.02.16.580700`.
- Erdrich, S.H., Schurr, U., Frunzke, J., Arsova, B. *Seed coating with phages for sustainable plant biocontrol of plant pathogens and influence of the seed coat mucilage* (preprint). bioRxiv. :doi:`10.1101/2024.01.12.575253`.
- Gaschignard, G., Millet, M., Bruley, A., Benzerara, K., Dezi, M., Skouri-Panet, F., Duprat, E., Callebaut, I. *AlphaFold2-guided description of CoBaHMA, a novel family of bacterial domains within the heavy-metal-associated superfamily*. Proteins. 2024 Jan 22. :doi:`10.1002/prot.26668`. :pmid:`38258321`.
- Jamali, K., L. Käll, R. Zhang, A. Brown, D. Kimanius, S.H.W. Scheres, 2023. *Automated model building and protein identification in cryo-EM maps* (preprint). bioRxiv. :doi:`10.1101/2023.05.16.541002`.
- Kautsar, S.A., J.J.J van der Hooft, D. de Ridder, M.H. Medema, 2021. *BiG-SLiCE: A highly scalable tool maps the diversity of 1.2 million biosynthetic gene clusters*. GigaScience 10, giaa154. :doi:`10.1093/gigascience/giaa154`.
- Komp, E., Alanzi, H. N., Francis, R., Vuong, C., Roberts, L., Mosallanejad, A., Beck, D. A. C. *Homologous Pairs of Low and High Temperature Originating Proteins Spanning the Known Prokaryotic Universe*. Sci Data 2023, 10 (1), 682. :doi:`10.1038/s41597-023-02553-w`.
- Konstantinidis, K., C. Ruiz-Perez, K. Gerhardt, L. Rodriguez-R, C. Jain, J. Tiedje, J. Cole, 2022. *FastAAI: Efficient Estimation of Genome Average Amino Acid Identity and Phylum-level relationships using Tetramers of Universal Protein* (preprint). ResearchSquare. :doi:`10.21203/rs.3.rs-1459378/v1`.
- Lienhard, M., T. van den Beucken, B. Timmermann, M. Hochradel, S. Boerno, F. Caiment, M. Vingron, R. Herwig, 2021. *Long-read transcriptome sequencing analysis with IsoTools* (preprint). Genetics. :doi:`10.1101/2021.07.13.452091`.
- Reynolds, R., Hyun, S., Tully, B., Bien, J., Levine, N. M. *Identification of microbial metabolic functional guilds from large genomic datasets*. Front Microbiol. 2023 Jun 30;14:1197329. :doi:`10.3389/fmicb.2023.1197329` :pmid:`37455725`.
